/*_____________________________________________________________________________

	Error & status defines
_____________________________________________________________________________*/
#ifndef __ERROR_HPP
#define __ERROR_HPP


// Typedef for values that convey status or error return values.
// Note adherance to the convention that 0 means success, !=0 means error.
// Functions which return XeStatus can still be tested for !=0 and we guarantee
// this will always work.
typedef enum XeStatus {
	xeFAILURE = -1,    			// Some failure, can't discern error
	xeSUCCESS = 0,		   		// No error.  Always 0, used for boolean checking.
	xeMEMORY = 1,			   	// Error allocating or locking memory
	xeSYNTAX = 2,			   	// Syntax error in some user input or config file.
	xeILLEGAL_PARAMETER = 3,   	// An illegal parameter value was passed to a routine
	xeOPERATING_SYSTEM = 4,	   	// Some error performing miscellaneous Windows API calls
	xeFILE_IO = 5,			   	// Some error performing file read/write/seek
	xeFILE_TYPE = 6,		   	// Unsupported file type
	xeFILE_CORRUPT = 7,		   	// Unrecognizeable data in file
	xeFILE_NOT_FOUND = 8,	   	// Can't find desired file
	xeVERSION = 9,			   	// Some component (DLL or other) not proper version
	xeCOMPONENT_NOT_FOUND = 10,	// Necessary program component not there, like a DLL
	xeILLEGAL_RESULT = 11,	   	// An illegal parameter value was passed to a routine
	xeNOT_INITIALIZED = 12,		// An object or data member not initialized yet.
	xeRANGE_EXCEEDED = 13,		// Some sort of range exceeded - array bounds, etc.
	xeNOT_IMPLEMENTED = 14		// Some feature or function not complete (yet)
};



#endif
